@@ -20,6 +20,7 @@ from __future__ import division, print_function, absolute_import
 import io
 import uuid
 import decimal
+import numbers
 import datetime
 import fractions
 import functools
@@ -28,7 +29,7 @@ import collections
 import hypothesis.strategies as st
 from hypothesis.errors import InvalidArgument, ResolutionFailed
 from hypothesis.internal.compat import PY2, ForwardRef, abc, text_type, \
-    typing_root_type
+    binary_type, typing_root_type
 
 
 def type_sorting_key(t):
@@ -133,7 +134,7 @@ _global_type_lookup = {
     fractions.Fraction: st.fractions(),
     decimal.Decimal: st.decimals(),
     text_type: st.text(),
-    bytes: st.binary(),
+    binary_type: st.binary(),
     datetime.datetime: st.datetimes(),
     datetime.date: st.dates(),
     datetime.time: st.times(),
@@ -150,6 +151,11 @@ _global_type_lookup = {
     type(NotImplemented): st.just(NotImplemented),
     bytearray: st.binary().map(bytearray),
     memoryview: st.binary().map(memoryview),
+    numbers.Real: st.floats(),
+    numbers.Rational: st.fractions(),
+    numbers.Number: st.complex_numbers(),
+    numbers.Integral: st.integers(),
+    numbers.Complex: st.complex_numbers(),
     # Pull requests with more types welcome!
 }
 
@@ -187,8 +193,8 @@ else:
         typing.Reversible: st.lists(st.integers()),
         typing.SupportsAbs: st.complex_numbers(),
         typing.SupportsComplex: st.complex_numbers(),
-        typing.SupportsFloat: st.complex_numbers(),
-        typing.SupportsInt: st.complex_numbers(),
+        typing.SupportsFloat: st.floats(),
+        typing.SupportsInt: st.floats(),
     })
 
     try:
